@@ -209,7 +209,7 @@ sig_tally.CopyNumber <- function(object,
     feature_setting$n_obs <- colSums(cn_matrix, na.rm = TRUE)
   } else if (startsWith(method, "S")) {
     # When use method "S", join_adj_seg should set to FALSE in read_copynumber
-    send_info("When you use method 'S', please make sure you have set 'join_adj_seg' to FALSE in 'read_copynumber() in the previous step!")
+    send_info("When you use method 'S', please make sure you have set 'join_adj_seg' to FALSE and 'add_loh' to TRUE in 'read_copynumber() in the previous step!")
     mat_list <- get_matrix_mutex_sv(data.table::rbindlist(cn_list, idcol = "sample"))
     cn_features <- NULL
     cn_components <- mat_list$data
